:py:mod:`arduino_serial_out_com`
================================

.. py:module:: arduino_serial_out_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = Arduino Serial Out

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Signal In']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input']

   

.. py:data:: ParameterNames
   :annotation: = ['Visualisation', 'COM Port', 'Baud Rate']

   

.. py:data:: ParameterTypes
   :annotation: = ['bool', 'str', 'int']

   

.. py:data:: ParametersDefaultValues
   :annotation: = [False, 'COM4', 9600]

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: arduino_serial_out_com
   

   

